KillSounds = {
	Announcers = {Classic=1, Female=2, Female2004=3, Male=4, Sexy=5, UT2003=6},
	CurrentAnnouncer = gkini.ReadString("killsounds", "announcer", "Male"),
	PlayerTime = gkini.ReadInt("killsounds", "playertime", 30),
	NPCTime = gkini.ReadInt("killsounds", "npctime", 10),
	ShowStartupMessage = gkini.ReadString("killsounds", "startupmessage", "ON"),
	PlayKillMessages = gkini.ReadString("killsounds", "playkillmessages", "YES"),
	PlaySpreeMessages = gkini.ReadString("killsounds", "playspreemessages", "YES"),
}

function KillSounds.LoadSoundPack()
	local announcer = KillSounds.CurrentAnnouncer
	local sound_dir = "plugins/UTAnnouncements/announcers/"..announcer.."/"
	local killmsgs = {
		{soundname=KillSounds.Announcers[announcer].."kill1", filename=sound_dir.."doublekill.wav"},
		{soundname=KillSounds.Announcers[announcer].."kill2", filename=sound_dir.."multikill.wav"},
		{soundname=KillSounds.Announcers[announcer].."kill3", filename=sound_dir.."megakill.wav"},
		{soundname=KillSounds.Announcers[announcer].."kill4", filename=sound_dir.."ultrakill.wav"},
		{soundname=KillSounds.Announcers[announcer].."kill5", filename=sound_dir.."monsterkill.wav"},
		{soundname=KillSounds.Announcers[announcer].."kill6", filename=sound_dir.."ludicrouskill.wav"},
		{soundname=KillSounds.Announcers[announcer].."kill7", filename=sound_dir.."holyshit.wav"},
		{soundname=KillSounds.Announcers[announcer].."spree5", filename=sound_dir.."killingspree.wav"},
		{soundname=KillSounds.Announcers[announcer].."spree10", filename=sound_dir.."rampage.wav"},
		{soundname=KillSounds.Announcers[announcer].."spree15", filename=sound_dir.."dominating.wav"},
		{soundname=KillSounds.Announcers[announcer].."spree20", filename=sound_dir.."unstoppable.wav"},
		{soundname=KillSounds.Announcers[announcer].."spree25", filename=sound_dir.."godlike.wav"},
		{soundname=KillSounds.Announcers[announcer].."spree30", filename=sound_dir.."wickedsick.wav"},
	}
	for i,v in ipairs(killmsgs) do gksound.GKLoadSound(v) end
end
KillSounds.LoadSoundPack()

function KillSounds.UpdateAnnouncer(announcer)
	KillSounds.CurrentAnnouncer = announcer
	gkini.WriteString("killsounds", "announcer", announcer)
	KillSounds.LoadSoundPack()
end
function KillSounds.UpdateTime(type, time)
	KillSounds[type.."Time"] = time
	gkini.WriteString("killsounds", type:lower().."time", time)
end
function KillSounds.UpdateShowStartupMessage(state)
	KillSounds.ShowStartupMessage = state
	gkini.WriteString("killsounds", "startupmessage", state)
end
function KillSounds.UpdatePlayKillMessages(state)
	KillSounds.PlayKillMessages = state
	gkini.WriteString("killsounds", "playkillmessages", state)
end
function KillSounds.UpdatePlaySpreeMessages(state)
	KillSounds.PlaySpreeMessages = state
	gkini.WriteString("killsounds", "playspreemessages", state)
end

local killtimer = Timer()
local killmsglevel = -1

local spreemsglevel = 0

local function reset_killmsgs()
	killmsglevel = -1
	if killtimer:IsActive() then killtimer:Kill() end
end
local function reset_spreemsgs()
	spreemsglevel = 0
end

function KillSounds.ProcessKill(victim, killer, time)
	if victim ~= GetCharacterID() then
		local should_delay
		if killtimer:IsActive() then
			killmsglevel = killmsglevel + 1
			if killmsglevel > 0 then
				killmsglevel = killmsglevel < 8 and killmsglevel or 7
				if KillSounds.PlayKillMessages == "YES" then
					gksound.GKPlaySound(KillSounds.Announcers[KillSounds.CurrentAnnouncer].."kill"..killmsglevel)
					should_delay = true
				end
			end
			killtimer:SetTimeout(time*1000)
		else
			killmsglevel = 0
			killtimer:SetTimeout(time*1000, reset_killmsgs)
		end
		spreemsglevel = spreemsglevel + 1
		if KillSounds.PlaySpreeMessages == "YES" then
			if should_delay then
				local timer = Timer()
				timer:SetTimeout(3000, function() gksound.GKPlaySound(KillSounds.Announcers[KillSounds.CurrentAnnouncer].."spree"..spreemsglevel) end)
			else
				gksound.GKPlaySound(KillSounds.Announcers[KillSounds.CurrentAnnouncer].."spree"..spreemsglevel)
			end
		end
	else
		reset_killmsgs()
		reset_spreemsgs()
	end
end

function KillSounds:OnEvent(event, ...)
	if event == "PLAYER_DIED" then
		local victim, killer, weaponid = ...
		local time
		if GetPlayerName(victim):match("^*") then time = KillSounds.NPCTime else time = KillSounds.PlayerTime end
		self.ProcessKill(victim, killer, time)
	elseif event == "PLAYER_ENTERED_GAME" and KillSounds.ShowStartupMessage == "ON" then
		purchaseprint("Unreal Tournament-style kill announcements loaded. Change the announcement voice and other settings with \"/UTSounds\".")
	elseif event == "ENTERED_STATION" then
		reset_killmsgs()
		reset_spreemsgs()
	end
end
RegisterEvent(KillSounds, "PLAYER_ENTERED_GAME")
RegisterEvent(KillSounds, "ENTERED_STATION")
RegisterEvent(KillSounds, "PLAYER_DIED")

dofile("ui.lua")